==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/cfw/v20190904/models/AddEnterpriseSecurityGroupRulesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cfw.v20190904.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AddEnterpriseSecurityGroupRulesResponse extends AbstractModel {

    /**
    * 状态值，0：添加成功，非0：添加失败
    */
    @SerializedName("Status")
    @Expose
    private Long Status;

    /**
    * 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Rules")
    @Expose
    private SecurityGroupSimplifyRule [] Rules;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 状态值，0：添加成功，非0：添加失败 
     * @return Status 状态值，0：添加成功，非0：添加失败
     */
    public Long getStatus() {
        return this.Status;
    }

    /**
     * Set 状态值，0：添加成功，非0：添加失败
     * @param Status 状态值，0：添加成功，非0：添加失败
     */
    public void setStatus(Long Status) {
        this.Status = Status;
    }

    /**
     * Get 规则uuid
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Rules 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     */
    public SecurityGroupSimplifyRule [] getRules() {
        return this.Rules;
    }

    /**
     * Set 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     * @param Rules 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setRules(SecurityGroupSimplifyRule [] Rules) {
        this.Rules = Rules;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public AddEnterpriseSecurityGroupRulesResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AddEnterpriseSecurityGroupRulesResponse(AddEnterpriseSecurityGroupRulesResponse source) {
        if (source.Status != null) {
            this.Status = new Long(source.Status);
        }
        if (source.Rules != null) {
            this.Rules = new SecurityGroupSimplifyRule[source.Rules.length];
            for (int i = 0; i < source.Rules.length; i++) {
                this.Rules[i] = new SecurityGroupSimplifyRule(source.Rules[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Status", this.Status);
        this.setParamArrayObj(map, prefix + "Rules.", this.Rules);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/cfw/v20190904/models/AddEnterpriseSecurityGroupRulesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cfw.v20190904.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AddEnterpriseSecurityGroupRulesResponse extends AbstractModel {

    /**
    * 状态值，0：添加成功，非0：添加失败
    */
    @SerializedName("Status")
    @Expose
    private Long Status;

    /**
    * 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Rules")
    @Expose
    private SecurityGroupSimplifyRule [] Rules;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 状态值，0：添加成功，非0：添加失败 
     * @return Status 状态值，0：添加成功，非0：添加失败
     */
    public Long getStatus() {
        return this.Status;
    }

    /**
     * Set 状态值，0：添加成功，非0：添加失败
     * @param Status 状态值，0：添加成功，非0：添加失败
     */
    public void setStatus(Long Status) {
        this.Status = Status;
    }

    /**
     * Get 规则uuid
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Rules 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     */
    public SecurityGroupSimplifyRule [] getRules() {
        return this.Rules;
    }

    /**
     * Set 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     * @param Rules 规则uuid
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setRules(SecurityGroupSimplifyRule [] Rules) {
        this.Rules = Rules;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public AddEnterpriseSecurityGroupRulesResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AddEnterpriseSecurityGroupRulesResponse(AddEnterpriseSecurityGroupRulesResponse source) {
        if (source.Status != null) {
            this.Status = new Long(source.Status);
        }
        if (source.Rules != null) {
            this.Rules = new SecurityGroupSimplifyRule[source.Rules.length];
            for (int i = 0; i < source.Rules.length; i++) {
                this.Rules[i] = new SecurityGroupSimplifyRule(source.Rules[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Status", this.Status);
        this.setParamArrayObj(map, prefix + "Rules.", this.Rules);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
